package dev.fitko.fitconnect.client.util;

import dev.fitko.fitconnect.api.domain.model.metadata.Metadata;
import dev.fitko.fitconnect.api.domain.model.metadata.PublicServiceType;
import dev.fitko.fitconnect.api.domain.model.metadata.Signature;
import dev.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import dev.fitko.fitconnect.api.domain.model.metadata.data.Data;
import org.junit.jupiter.api.Test;

import java.util.List;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;

public class SubmissionUtilTest {

    @Test
    public void buildMetadata() {

        Signature signature = new Signature();
        signature.setContent("content");
        Data data = new Data();
        data.setSignature(signature);

        Attachment attachment1 = new Attachment();
        attachment1.setFilename("fileName1");
        Attachment attachment2 = new Attachment();
        attachment2.setFilename("fileName2");
        List<Attachment> attachments = List.of(attachment1, attachment2);

        PublicServiceType publicServiceType = new PublicServiceType();
        publicServiceType.setName("publicService");

        Metadata metadata = SubmissionUtil.buildMetadata(attachments, data, publicServiceType);

        assertThat(metadata.getSchema(), is(Metadata.SCHEMA_URL));
        assertThat(metadata.getContentStructure().getAttachments().size(), is(2));
        assertThat(metadata.getContentStructure().getAttachments().get(0).getFilename(), is("fileName1"));
        assertThat(metadata.getContentStructure().getAttachments().get(1).getFilename(), is("fileName2"));
        assertThat(metadata.getContentStructure().getData().getSignature().getContent(), is("content"));
        assertThat(metadata.getPublicServiceType().getName(), is("publicService"));
    }
}
